==> haskell-statistics-0.15.2.0-202-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 statistics
version:              0.15.2.0
visibility:           public
id:                   statistics-0.15.2.0-GOdOd0sMdPvCbhKefoXWgS
key:                  statistics-0.15.2.0-GOdOd0sMdPvCbhKefoXWgS
license:              BSD-2-Clause
copyright:            2009-2014 Bryan O'\''Sullivan
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Alexey Khudaykov <alexey.skladnoy@gmail.com>

author:
    Bryan O'\''Sullivan <bos@serpentine.com>, Alexey Khudaykov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/bos/statistics
synopsis:             A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.

    The library'\''s facilities can be divided into four broad categories:

    * Working with widely used discrete and continuous probability
    distributions.  (There are dozens of exotic distributions in use;
    we focus on the most common.)

    * Computing with sample data: quantile estimation, kernel density
    estimation, histograms, bootstrap methods, significance testing,
    and regression and autocorrelation analysis.

    * Random variate generation under several different distributions.

    * Common statistical tests for significant differences between
    samples.

category:             Math, Statistics
abi:                  2ed383c4cc1ed5c1718c72f0b955cdf3
exposed:              True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Normal
    Statistics.Distribution.Poisson Statistics.Distribution.StudentT
    Statistics.Distribution.Transform Statistics.Distribution.Uniform
    Statistics.Function Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.Internal Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Normalize
    Statistics.Sample.Powers Statistics.Test.ChiSquared
    Statistics.Test.KolmogorovSmirnov Statistics.Test.KruskalWallis
    Statistics.Test.MannWhitneyU Statistics.Test.StudentT
    Statistics.Test.Types Statistics.Test.WilcoxonT
    Statistics.Transform Statistics.Types

hidden-modules:
    Statistics.Distribution.Poisson.Internal Statistics.Internal
    Statistics.Test.Internal Statistics.Types.Internal

import-dirs:          /usr/lib/ghc-9.0.1/site-local/statistics-0.15.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/statistics-0.15.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/statistics-0.15.2.0
hs-libraries:         HSstatistics-0.15.2.0-GOdOd0sMdPvCbhKefoXWgS
depends:
    aeson-1.5.6.0-FCXpoR7la5e15i9FMLdjlO
    async-2.2.3-9JPY7l8fhbkJIfTf8ClMWi base-4.15.0.0
    base-orphans-0.8.5-Ij3eXQiK047KNbYsRaIDPj binary-0.8.8.0
    data-default-class-0.1.2.0-LBmwYNzg9cwLSaLiX5AQfC deepseq-1.4.5.0
    dense-linear-algebra-0.1.0.0-DjVtpVHfRl8GjOCVEx4aBr
    math-functions-0.3.4.2-B9R9xamW9dDLqnCt3M9JxZ
    monad-par-0.3.5-3uddOPm3OuUGa1CsDKiMr7
    mwc-random-0.15.0.2-JhuYdprY5QdLnU6XfjS2bD
    primitive-0.7.2.0-984pU99uyia2hUwO3CJO8M
    vector-0.12.3.1-EtdN61cdG6Y4MwC0gVwGz6
    vector-algorithms-0.8.0.4-6cmJZv7z8OSJD7WCSSaJqF
    vector-binary-instances-0.2.5.2-9DGcPV8qi5H1mKDoAAqcln
    vector-th-unbox-0.2.2-5gum95FoezWC1irlJTkZVR

haddock-interfaces:   /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html:         /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-statistics-0.15.2.0-218-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 statistics
version:              0.15.2.0
visibility:           public
id:                   statistics-0.15.2.0-A1TzCTwYG8QMO32lxnFV
key:                  statistics-0.15.2.0-A1TzCTwYG8QMO32lxnFV
license:              BSD-2-Clause
copyright:            2009-2014 Bryan O'\''Sullivan
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Alexey Khudaykov <alexey.skladnoy@gmail.com>

author:
    Bryan O'\''Sullivan <bos@serpentine.com>, Alexey Khudaykov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/bos/statistics
synopsis:             A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.

    The library'\''s facilities can be divided into four broad categories:

    * Working with widely used discrete and continuous probability
    distributions.  (There are dozens of exotic distributions in use;
    we focus on the most common.)

    * Computing with sample data: quantile estimation, kernel density
    estimation, histograms, bootstrap methods, significance testing,
    and regression and autocorrelation analysis.

    * Random variate generation under several different distributions.

    * Common statistical tests for significant differences between
    samples.

category:             Math, Statistics
abi:                  448ad819677374e868940976ff031d7b
exposed:              True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Normal
    Statistics.Distribution.Poisson Statistics.Distribution.StudentT
    Statistics.Distribution.Transform Statistics.Distribution.Uniform
    Statistics.Function Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.Internal Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Normalize
    Statistics.Sample.Powers Statistics.Test.ChiSquared
    Statistics.Test.KolmogorovSmirnov Statistics.Test.KruskalWallis
    Statistics.Test.MannWhitneyU Statistics.Test.StudentT
    Statistics.Test.Types Statistics.Test.WilcoxonT
    Statistics.Transform Statistics.Types

hidden-modules:
    Statistics.Distribution.Poisson.Internal Statistics.Internal
    Statistics.Test.Internal Statistics.Types.Internal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/statistics-0.15.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/statistics-0.15.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/statistics-0.15.2.0
hs-libraries:         HSstatistics-0.15.2.0-A1TzCTwYG8QMO32lxnFV
depends:
    aeson-1.5.6.0-3UkULX00zZS4WfonZkjdLx
    async-2.2.3-7pljJfCB7e74FDaNZigg6K base-4.15.1.0
    base-orphans-0.8.5-KLeBym8JKYaHXs579gDd0W binary-0.8.8.0
    data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO deepseq-1.4.5.0
    dense-linear-algebra-0.1.0.0-Lhh4KBH8yVVESmwSGnYzp9
    math-functions-0.3.4.2-4s3LFPSaHJd6r3VBjfJCmD
    monad-par-0.3.5-2dUp8iPzdNH2IS51rwks8g
    mwc-random-0.15.0.2-Jh4sxWBF7Rz3J2wZQ6mUfQ
    primitive-0.7.3.0-9BbAgPS3yUyHY7eNW9n2jO
    vector-0.12.3.1-JI8sEYS2DW2BwfKSRTijMW
    vector-algorithms-0.8.0.4-CV6n2fuxg2ACSgzbIPQfHU
    vector-binary-instances-0.2.5.2-FEFRxy6fAui4rRCF8NL6u7
    vector-th-unbox-0.2.2-1MswUt7eZP9Gaele7usNPo

haddock-interfaces:   /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html:         /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
